##
##  openjpeg.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2018 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 2.1.0
%define       V_dist 2.1

#   package information
Name:         openjpeg
Summary:      Joint Photographic Experts Group (JPEG) Image Library
URL:          http://www.openjpeg.org/
Vendor:       OpenJPEG et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Graphics
License:      BSD
Version:      %{V_opkg}
Release:      20181104

#   list of sources
Source0:      https://github.com/uclouvain/openjpeg/archive/version.%{V_dist}.tar.gz
Patch0:       openjpeg.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, cmake
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  zlib, png, jpeg, lcms
PreReq:       zlib, png, jpeg, lcms

%description
    JPEG (pronounced "jay-peg") is a standardized image compression
    mechanism. JPEG stands for Joint Photographic Experts Group, the
    original name of the committee that wrote the standard.

%track
    prog openjpeg = {
        version   = %{version}
        url       = https://github.com/uclouvain/openjpeg/releases
        regex     = openjpeg-(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n openjpeg-version.%{V_dist}
    %patch -p0

%build
    DESTDIR=$RPM_BUILD_ROOT%{l_prefix} \
    cmake \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_C_STANDARD_LIBRARIES="-ljpeg" \
        -DBUILD_SHARED_LIBS=OFF \
        -DBUILD_THIRDPARTY=OFF \
        -DOPENJPEG_INSTALL_INCLUDE_DIR=%{l_prefix}/include \
        -DOPENJPEG_INSTALL_SHARE_DIR=%{l_prefix}/share/openjpeg \
        -DOPENJPEG_INSTALL_MAN_DIR=%{l_prefix}/man \
        -DOPENJPEG_INSTALL_DOC_DIR=%{l_prefix}/share/openjpeg/doc \
        -DZLIB_LIBRARY="%{l_prefix}/lib/libz.a" \
        -DZLIB_INCLUDE_DIR="%{l_prefix}/include" \
        -DPNG_LIBRARY="%{l_prefix}/lib/libpng.a" \
        -DPNG_INCLUDE_DIR="%{l_prefix}/include" \
        -DTIFF_LIBRARY="%{l_prefix}/lib/libtiff.a" \
        -DTIFF_INCLUDE_DIR="%{l_prefix}/include/tiff" \
        -DLCMS2_LIBRARY="%{l_prefix}/lib/liblcms2.a" \
        -DLCMS2_INCLUDE_DIR="%{l_prefix}/include" \
        .
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

